@@ -62,6 +62,7 @@ static cfgopt_t cfg[] = {
 	{ 't', "interval",      CONFIG_DEC, {}, "86400", "output file rotation interval" },
 	{ 'c', "count",         CONFIG_DEC, {}, NULL,    "packet count limit" },
 	{ 'H', "headersonly",   CONFIG_BOOL,{}, "0",     "dump headers only" },
+	{ 'S', "sample",        CONFIG_DEC, {}, "0",     "sample value" },
 	{ 'w', "filefmt",       CONFIG_STR, {}, NULL,    "output file format" },
 	{ 'P', "pidfile",       CONFIG_STR, {}, NULL,    "pid file" },
 	cfgopt_cfgfile,
@@ -85,9 +86,13 @@ static int64_t total_count_packets;
 static time_t time_lastdump;
 static time_t time_start;
 
+static int pcapdump_sample;
+static int pcapdump_sample_value;
+
 /* forward declarations */
 
 static bool has_config_changed(void);
+static bool should_sample(void);
 static inline bool is_new_interval(time_t t);
 static void check_interval_and_reset(void);
 static void close_and_exit(void);
@@ -208,6 +213,8 @@ static void process_packet(u_char *user __unused, const struct pcap_pkthdr *hdr,
 	}
 	if(is_new_interval(hdr->ts.tv_sec))
 		reset_dump();
+	if(pcapdump_sample > 0 && !should_sample())
+		return;
 	if(unlikely(!headers_only)){
 		pcap_dump((u_char *) pa.dumper, hdr, pkt);
 		++count_packets;
@@ -230,6 +237,16 @@ static void process_packet(u_char *user __unused, const struct pcap_pkthdr *hdr,
 	return;
 }
 
+static bool should_sample(void){
+	if(--pcapdump_sample_value == 0){
+		pcapdump_sample_value = pcapdump_sample;
+		return true;
+	}else{
+		return false;
+	}
+	return true;
+}
+
 static inline bool is_new_interval(time_t t){
 	if(
 		(pcapdump_interval > 0) &&
@@ -358,6 +375,7 @@ static void parse_args(int argc, char **argv){
 	if((cur = cfgopt_get(cfg, "configfile")) && cur->val.str && cur->val.str[0] != '/')
 		usage("use fully qualified config file path");
 	headers_only = cfgopt_get_bool(cfg, "headersonly");
+	pcapdump_sample = pcapdump_sample_value = cfgopt_get_num(cfg, "sample");
 }
 
 static void usage(const char *msg){
