@@ -129,6 +129,57 @@ const u_char *pcapnet_start_network_header(
 	return pkt;
 }
 
+const u_char *pcapnet_start_transport_header(
+		int datalink,
+		const u_char *orig_pkt,
+		size_t *len /* modified */,
+		u8 *proto /* modified */
+		){
+	int etype = 0;
+	size_t net_len = *len;
+	const u_char *pkt = pcapnet_start_network_header(datalink, orig_pkt, &etype, &net_len);
+	if(!pkt)
+		return NULL;
+	switch(etype){
+		struct iphdr *ip;
+		struct ip6hdr *ip6;
+
+		case ETHERTYPE_IP:
+			ip = (void *) pkt;
+			if(*len < sizeof(struct iphdr) || *len < (4U * ip->ihl))
+				return NULL;
+			*len -= 4 * ip->ihl;
+			pkt += 4 * ip->ihl;
+			*proto = ip->protocol;
+			break;
+
+		case ETHERTYPE_IPV6:
+			ip6 = (void *) pkt;
+			if(*len < sizeof(struct ip6hdr))
+				return NULL;
+			*len -= sizeof(struct ip6hdr);
+			pkt += sizeof(struct ip6hdr);
+			*proto = ip6->ip6_nxt;
+			break;
+
+		default:
+			return NULL;
+	}
+	switch(*proto){
+		case IPPROTO_TCP:
+			if(*len < sizeof(struct tcphdr))
+				return NULL;
+		case IPPROTO_UDP:
+			if(*len < sizeof(struct udphdr))
+				return NULL;
+		case IPPROTO_ICMPV6:
+		case IPPROTO_ICMP:
+			if(*len < ICMP_HLEN)
+				return NULL;
+	}
+	return pkt;
+}
+
 const u_char *pcapnet_start_app_layer(
 		int datalink,
 		const u_char *orig_pkt,
